local _, NS = ...

function NS:BuildOptions(name, addon)
  return {
    name = name,
    handler = addon,
    type = "group",
    set = "SetOption",
    get = "GetOption",
    args = {
      description = {
        order = 1,
        type = "description",
        name = "OrganizedPanic helps your party members avoid casting expensive cooldowns at the same time."
      },
      display_settings = {
        order = 2,
        type = "group",
        name = "Display Settings",
        inline = true,
        args = {
          help = {
            type = "description",
            name = "The display of the flashing border can be customized by changing the options below.",
            order = 1,
          },
          flash_border = {
            order = 2,
            type = "toggle",
            name = "Flash Border",
            desc = "Flash border when another player casts a cooldown?",
            arg = "flashBorder",
          },
          border_color = {
            order = 3,
            type = "color",
            name = "Border color",
            desc = "The color of the flashing border.",
            set = "SetBorderColor",
            get = "GetBorderColor"
          },
        }
      },
      sound_settings = {
        order = 3,
        type = "group",
        name = "Sound Settings",
        inline = true,
        args = {
          help = {
            order = 1,
            type = "description",
            name = "Sounds can be customized by changing the options below.",
          },
          play_sound = {
            order = 2,
            type = "toggle",
            name = "Play Sound",
            desc = "Play sound when another player casts a cooldown?",
            arg = "playSound",
          },
          sound_select = {
            order = 3,
            type = "select",
            name = "Sound",
            desc = "The sound to play when another layer casts a cooldown.",
            arg = "sound",
            values = {
              ["artifact"] = "Artifact",
              ["azerite"] = "Azerite",
              ["legendary"] = "Legendary",
              ["objectivecomplete"] = "Objective Complete",
              ["auctionhouse"] = "Auction House",
              ["auctionclose"] = "Auction House Close",
              ["raidwarning"] = "Raid Warning",
              ["raidbosswarning"] = "Raid Boss Warning",
              ["raidbosswhisperwarning"] = "Raid Boss Whisper Warning",
            }
          }
        },
      },
      test_group = {
        order = 4,
        type = "group",
        name = "Testing",
        inline = true,
        args = {
          group_1 = {
            order = 1,
            type = "group",
            name = "",
            inline = true,
            args = {
              test_sound = {
                type = "execute",
                order = 1,
                name = "Panic!",
                desc = "Test the sound and flash.",
                func = function(info)
                  local ids = {68251, 55344, 70243, 141453, 268634, 133937, 156736, 299381, 205751, 288901}
                  -- for k,v in pairs(ids) do print(v, GetSpellInfo(v)) end
                  info.handler:Panic(info.handler.name, ids[math.random(#ids)])
                end
              },
            },
          },
        },
      },
      include_group = {
        order = 5,
        type = "group",
        name = "Inclusion",
        inline = true,
        args = {
          group_1 = {
            order = 1,
            type = "group",
            name = "",
            inline = true,
            args = {
              include_self_toggle = {
                order = 1,
                type = "toggle",
                name = "Include Self",
                desc = "Include self when warning about casts?",
                arg = "includeSelf",
              },
              include_role_toggle = {
                order = 2,
                type = "toggle",
                name = "Include Role Only",
                desc = "Include spells from my role only?",
                arg = "includeRole",
              },
            },
          },
        },
      },
      help_group = {
        order = 6,
        type = "group",
        name = "Chat Commands",
        inline = true,
        args = {
          group_1 = {
            order = 1,
            type = "group",
            name = "",
            inline = true,
            args = {
              help_text_1 = {
                order = 1,
                type = "description",
                name = "/op todo - TODO :)"
              },
            },
          },
        },
      },
      debug_group = {
        order = 6,
        type = "group",
        name = "Debug Options",
        inline = true,
        args = {
          group_1 = {
            order = 1,
            type = "group",
            name = "",
            inline = true,
            args = {
              debug_toggle = {
                order = 1,
                type = "toggle",
                name = "Debug Mode",
                desc = "Show lots of annoying debug output?",
                arg = "debug",
              },
            },
          },
        },
      },
    }
  }
end
